#!/usr/bin/python3
# -*- coding: utf-8 -*-
# @Time    : 2024/8/7 8:54
# @Author  : wangqinggang
# @Email   : wqg1993@qq.com
# @File    : __init__.py
__version__ = "0.0.0"
from .subscriber import DxrSubscriber
